# frozen_string_literal: true

#
# Cookbook:: snu_awscli
# Library:: resource/snu_awscli
#
# Copyright:: 2018, Socrata, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require 'chef/resource'

class Chef
  class Resource
    # A custom resource for managing awscli installs.
    #
    # @author Jonathan Hartman <jonathan.hartman@tylertech.com>
    class SnuAwscli < Resource
      default_action :install

      property :version, String

      #
      # Install or upgrade awscli in a Python 3 virtualenv and symlink it into
      # /usr/local/bin.
      #
      %i[install upgrade].each do |act|
        action act do
          python_runtime '3'

          python_virtualenv '/opt/awscli' do
            python '3'
          end

          python_package 'awscli' do
            virtualenv '/opt/awscli'
            version new_resource.version unless new_resource.version.nil?
            action act
          end

          link '/usr/local/bin/aws' do
            to '/opt/awscli/bin/aws'
          end
        end
      end

      #
      # Delete the awscli symlink and virtualenv. We can't be sure the Python 3
      # runtime isn't in use by other apps, so it has to be left behind.
      #
      action :remove do
        link('/usr/local/bin/aws') { action :delete }
        python_virtualenv('/opt/awscli') { action :delete }
      end
    end
  end
end
